# This short Python V3 demonstration program remotely controls a NET16PRMx board
# using TCP/IP and the normal EasyDaq command set, demostrating input and output.
# The program turns on the 16 individual relays in a sequence and reads the 8 bit input port

import socket    # used for TCP/IP communication
import time      # used for display
import sys       # display of data read back from the board.
import signal    # intercept SIGINT (Ctrl-C) to end demo.
import array     # Array handling

# Define the IP address of the NET16.
TCP_IP = '10.26.177.231' # Set this to the IP address of your NET16
TCP_PORT = 10001 # Do not change this - it is pre-defined in the Lantronix XPort module.
BUFFER_SIZE = 1 # How many bytes to read back from board

# Introduction
print ("\nEasyDaq TCP/IP demonstration of the NET16 board")
print ("(Hit Ctrl-c to end)\n")
time.sleep(1)

# Open TCP/IP socket
s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
s.connect((TCP_IP, TCP_PORT))

# Define a signal handler to catch when the user quits using Ctrl-C and then tidy up
def signal_handler(signal, frame):
 print('\n\n\n      *** Thank you for trying the EasyDaq NET16 *** \nFor further information please visit http://www.easydaq.co.uk\n')
 s.send(array.array('B',[0x43,0x00])) # PIC port B to off
 time.sleep(0.1)
 s.send(array.array('B',[0x46,0x00])) # PIC port C to off
 time.sleep(0.1)
 s.close()
 sys.exit(0)

signal.signal(signal.SIGINT, signal_handler) # Register the signal handler

# Configure the NET16 ports for input/output
s.send(array.array('B',[0x42,0x00]))    # Set PIC port B, to O/P
time.sleep(0.100) # Allow the board to settle.
s.send(array.array('B',[0x45,0x00]))    # Set PIC port C to O/P
time.sleep(0.100) # Allow the board to settle.
s.send(array.array('B',[0x48,0xFF]))    # Set PIC port D to I/P
time.sleep(0.100) # Allow the board to settle.

# Send random numbers to RLY1 to RLY16, whilst reading from PIC port D and displaying value

while True:
    OutByte = 1
    while OutByte < 255:
        s.send(array.array('B',[0x43,OutByte]))
        OutByte = OutByte * 2
        time.sleep(0.100)
    s.send(array.array('B', [0x43, 0]))
    time.sleep(0.100)
    OutByte = 1
    while OutByte < 255:
        s.send(array.array('B', [0x46, OutByte]))
        OutByte = OutByte * 2
        time.sleep(0.100)
    s.send(array.array('B', [0x46, 0]))
    time.sleep(0.100)
    s.send(array.array('B', [0x47, 0x00,0x0D,0x0A])) # Set PIC Read port D; Not sure if the CR & LF are required
    sys.stdout.write("\r"+ time.ctime() + ":  " + format(ord(s.recv(BUFFER_SIZE)),'b').zfill(8));
    sys.stdout.flush()

# Tidy up...
s.send(array.array('B',[0x43,0x00])) # PIC port B to off
time.sleep(0.1)
s.send(array.array('B',[0x46,0x00])) # PIC port C to off
time.sleep(0.1)

s.close()
sys.exit(0)
